@@ -27,5 +27,5 @@ void iqmc_error__(const char* const msg,
                   const int line) {
 	char error_buffer[255];
 	snprintf(error_buffer, 255, "(%s:%d) %s", file, line, msg);
-	error(error_buffer);
+	error("%s", error_buffer);
 }
